@@ -29,7 +29,7 @@ def random_string(number_character, is_human_mistake_safe=False):
 
 def random_number(number_character):
     if number_character and type(number_character) is int and number_character>=0:
-        return ''.join(random.sample(NUMERIC_CHARS, number_character))
+        return ''.join([random.choice(NUMERIC_CHARS) for _ in range(number_character)])
     else:
         return ''
 
